package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcCarApproval;
import com.ruoyi.oa.service.ICmcCarApprovalService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc用车审批Controller
 * 
 * @author cmc
 * @date 2024-02-23
 */
@RestController
@RequestMapping("/oa/approval")
public class CmcCarApprovalController extends BaseController
{
    @Autowired
    private ICmcCarApprovalService cmcCarApprovalService;

    /**
     * 查询cmc用车审批列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcCarApproval cmcCarApproval)
    {
        startPage();
        List<CmcCarApproval> list = cmcCarApprovalService.selectCmcCarApprovalList(cmcCarApproval);
        return getDataTable(list);
    }

    /**
     * 导出cmc用车审批列表
     */
    @Log(title = "cmc用车审批", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcCarApproval cmcCarApproval)
    {
        List<CmcCarApproval> list = cmcCarApprovalService.selectCmcCarApprovalList(cmcCarApproval);
        ExcelUtil<CmcCarApproval> util = new ExcelUtil<CmcCarApproval>(CmcCarApproval.class);
        util.exportExcel(response, list, "cmc用车审批数据");
    }

    /**
     * 获取cmc用车审批详细信息
     */
    @GetMapping(value = "/{carApplyId}")
    public AjaxResult getInfo(@PathVariable("carApplyId") String carApplyId)
    {
        return success(cmcCarApprovalService.selectCmcCarApprovalByCarApplyId(carApplyId));
    }

    /**
     * 新增cmc用车审批
     */
    @Log(title = "cmc用车审批", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcCarApproval cmcCarApproval)
    {
        return toAjax(cmcCarApprovalService.insertCmcCarApproval(cmcCarApproval));
    }

    /**
     * 修改cmc用车审批
     */
    @Log(title = "cmc用车审批", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcCarApproval cmcCarApproval)
    {
        return toAjax(cmcCarApprovalService.updateCmcCarApproval(cmcCarApproval));
    }

    /**
     * 删除cmc用车审批
     */
    @Log(title = "cmc用车审批", businessType = BusinessType.DELETE)
	@DeleteMapping("/{carApplyIds}")
    public AjaxResult remove(@PathVariable String[] carApplyIds)
    {
        return toAjax(cmcCarApprovalService.deleteCmcCarApprovalByCarApplyIds(carApplyIds));
    }
}
